import { useState, useEffect } from "react";
import { Navigate } from "react-router-dom";
import { IOCDeployDialog } from "../IOCDeployDialog";
import { useStartJobMutation } from "../../../store/deployApi";

export function DeployIOC({
  open,
  setOpen,
  submitCallback,
  ioc,
  hasActiveDeployment,
  deployIocFormDefaults = {}
}) {
  const [error, setError] = useState(null);
  const [deploy, { data: deployment, error: deployError, isLoading }] =
    useStartJobMutation();

  useEffect(() => {
    if (deployError) {
      setError(deployError);
    }
  }, [deployError]);

  if (!deployment) {
    return (
      <IOCDeployDialog
        open={open}
        setOpen={setOpen}
        iocId={ioc.id}
        submitCallback={deploy}
        deployIocFormDefaults={deployIocFormDefaults}
        hasActiveDeployment={hasActiveDeployment}
        error={error}
        resetError={() => setError(null)}
        buttonDisabled={ioc.operationInProgress || isLoading}
      />
    );
  } else {
    submitCallback(); // This works but throws a warning because I am changing state in the parent while the child is rerendering. Not sure yet how to fix.
    return (
      <Navigate
        to={`/jobs/${deployment.id}`}
        push
      />
    );
  }
}
